
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 96
#define YY_END_OF_BUFFER 97
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[434] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   97,   95,
       24,   89,   88,   23,   25,   60,   91,   95,   23,   22,
       20,   25,   31,   20,   95,   25,   95,   95,   95,   95,
       95,   95,   24,   88,   25,   60,   91,   95,   22,   31,
       28,   96,   28,   28,   56,   56,   44,   56,   56,   46,
       48,   51,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   53,   53,   53,   78,   78,   87,   87,   36,   35,
       34,   36,   69,   64,   69,   68,   43,   69,   69,   45,

       47,   61,   69,   69,   69,   69,   69,   69,   69,   69,
       63,   63,   63,   75,   75,   84,   84,   72,   72,   81,
       81,   92,   94,   93,   96,   96,   96,   96,   96,   57,
       38,    0,   90,    0,   22,   22,   22,   22,    0,    0,
        0,   58,    0,   20,   29,    0,    0,    0,    0,   25,
       23,   20,   79,   70,   19,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    2,    0,   38,    1,
       22,   22,    0,    0,    0,   55,    0,   48,   48,   48,
       48,    0,    0,    0,    0,   40,    0,    0,    0,    0,
        0,    0,    0,   85,   76,    0,   55,    0,    0,   77,

       86,    0,    0,   32,   32,    0,    0,    0,    0,    0,
       65,    0,    0,   66,   66,    0,    0,    0,    0,    0,
       47,   47,   47,   47,    0,    0,    0,    0,   39,    0,
        0,    0,    0,    0,    0,    0,   82,   73,    0,    0,
        0,   74,   83,   71,   80,   93,    0,    0,    0,    0,
        0,    0,    0,    0,   22,    0,   22,    0,    0,    0,
        0,    0,   17,    0,    0,    0,    0,    0,    0,    0,
       20,    0,    0,    4,   18,   19,   19,   19,   19,   19,
       19,   19,   37,    0,    5,    0,   48,    0,   48,    0,
       42,    6,   54,    0,    7,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    8,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   47,    0,
       47,    0,   41,    9,    0,   10,   11,   93,    0,   14,
        0,    0,    0,    0,   16,    0,   59,    0,   15,   30,
       15,    0,    0,    0,    0,    0,    0,    0,    0,   16,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   26,    0,    0,   27,    0,   52,
        0,   33,    0,    0,    0,    0,   67,    0,    0,    0,
        0,   62,    0,    0,   13,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   13,    0,    3,   12,    3,    0,    0,
        0,    0,    0,   21,    0,    0,    0,   50,   49,    0,
        0,    0,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    6,    7,    8,    9,   10,    6,    1,
        1,   11,   12,   13,   12,   14,   15,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,    6,    6,   10,
       10,   10,    6,   10,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
        1,   18,    1,    1,   10,   19,   20,   21,   22,   23,

       24,   17,   25,   26,   27,   17,   17,   28,   29,   30,
       31,   32,   17,   33,   34,   35,   36,   17,   17,   37,
       17,   17,   38,   39,   40,   41,    1,   42,   43,   44,
       45,   45,   45,   45,   46,   47,   48,   49,   50,   51,
       52,   53,   54,   55,   56,   45,   57,   58,   59,   45,
       45,   60,   61,   62,   63,   64,   65,   45,   66,   45,
       45,   67,   45,   45,   45,   68,   45,   45,   45,   67,
       67,   69,   69,   69,   69,   69,   70,   70,   70,   70,
       70,   70,   71,   70,   70,   72,   72,   73,   72,   72,
       72,    1,    1,   74,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,   75,   75,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   76,   77,   78,   78,   78,
       78,   78,   78,   78,   78,   78,   78,   78,   79,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[80] =
    {   0,
        1,    2,    2,    2,    2,    1,    1,    2,    1,    1,
        2,    1,    1,    1,    1,    1,    3,    1,    2,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    1,    4,    1,
        1,    5,    5,    6,    5,    5,    5,    5,    6,    6,
        6,    6,    6,    6,    6,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    6,    5,    7,    8,
        8,    8,    9,    1,    4,   10,   10,   10,   10
    } ;

static const flex_int16_t yy_base[477] =
    {   0,
        0,   78,   78,   79,  153,  227,   81,   84,   85,   88,
       90,   92,   97,  101,  301,  375,  103,  108,   93,  100,
      104,  105,  106,  107,  109,  112,  449,  526, 1091, 1570,
     1570, 1570, 1570, 1570, 1570,  130, 1078,  103, 1061,  128,
      190,  118, 1570,  604,  113,  200,  212, 1005,  124, 1033,
        0, 1001,  216,  235,  120,  290,  125,  134,  129, 1054,
     1570, 1570, 1030, 1052, 1570, 1058, 1570,  156, 1047, 1570,
      210, 1570,  149, 1039,  182,  158,  198, 1040,  235,  999,
     1030, 1570, 1006,  992, 1570,  991, 1570,  988, 1570, 1570,
      682,  983, 1570, 1570, 1010,  760, 1570,  238,  997, 1570,

      256, 1570,  202,  988,  228,  179,  233,  979,  255,  956,
     1570,  968,  954, 1570,  955, 1570,  954, 1570,  953, 1570,
      948, 1570, 1570, 1570,  914,  254,  942,    0,  909, 1570,
     1570,  952, 1570,  944,  283,  247,  258,  286,  146,  264,
      954, 1570,  945,  297, 1570,  211,  911,    0,    0, 1570,
     1570,  927, 1570, 1570,  340,  296,    0,  797,    0,    0,
        0,  319,  347,  942,  271,  932, 1570,  183,  930, 1570,
      309,  355,  902,  870,  900, 1570,  902,  378,  331,  372,
      391,  306,  297,  895,  893, 1570,  890,  873,  877,  883,
      882,  854,  852, 1570, 1570,  831,  875,  845,  825, 1570,

     1570,  354,  860,    0, 1570,  327,  812,    0,    0,  792,
     1570,  390,  823,    0, 1570,  339,  787,    0,    0,  811,
      392,  398,  401,  405,  408,  392,  793,  791, 1570,  788,
      775,  781,  787,  787,  774,  771, 1570, 1570,  750,  767,
      729, 1570, 1570, 1570, 1570, 1570,  382,    0,  814,    0,
        0,    0,  410,  432,  425,  762,  760,  757,  695,  721,
      714,  678, 1570,  479,  738,    0,  690,    0,    0,    0,
      721,  866,  721, 1570,  528,  466,  549,  559,  643,  654,
      658,  690, 1570,  432, 1570,  723,  438,  707,  682,  678,
     1570, 1570, 1570,  667, 1570,  678,  617,  637,  634,  600,

      944,    0,  626,    0,    0,    0, 1570,  655,  593,  619,
      615,  578, 1022,    0,  603,    0,    0,    0,  462,  624,
      621,  621, 1570, 1570,  610, 1570, 1570, 1570,  425, 1570,
      553, 1059, 1073,  627, 1570,  599, 1570,  605,    0, 1570,
     1570,  524,  402,  551,    0,  508,  536,  565,  568, 1570,
      520,  486,  510,  477,  504,  471,  500,  445,  474,  430,
      458,  420,  443,  392, 1570,  432,  418, 1570,  422, 1570,
      501, 1570,  610, 1097, 1111,  576, 1570,  894, 1135, 1149,
      415, 1570,  400,  407, 1570,  972,    0, 1173,    0,    0,
        0, 1187,  384, 1240,  436,  634,  446, 1203,  491, 1209,

      505, 1080,  523, 1219,  576, 1225,  581, 1235,  359,  289,
      345,  327,  325, 1570,  696, 1570, 1570, 1570,  310,  308,
      292,  282,  263, 1570,  246,  228,  170, 1570, 1570,  856,
      141,  141, 1570, 1301, 1311, 1321, 1331, 1341, 1351, 1361,
     1371, 1381, 1391, 1401, 1411, 1421, 1430, 1436, 1441, 1446,
     1455, 1461, 1466, 1471, 1476, 1481, 1486, 1488,  146, 1493,
     1498, 1503,  128, 1505, 1510, 1515, 1517, 1522, 1530, 1535,
     1540,   89, 1545, 1550, 1555, 1560
    } ;

static const flex_int16_t yy_def[477] =
    {   0,
      433,    1,  434,  434,  435,  435,  436,  436,  437,  437,
      438,  438,  439,  439,  440,  440,  441,  441,  442,  442,
      443,  443,  444,  444,  445,  445,  446,  446,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      447,  433,  433,  447,  433,  433,  433,  433,  433,  448,
      449,  450,  433,  433,  451,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,

      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  452,  453,  454,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,   44,  433,  433,  455,  456,  457,  433,
      433,  144,  433,  433,  433,  433,  458,  433,  458,  458,
      458,  433,  433,  433,  433,  451,  433,  451,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,

      433,  433,  433,  459,  433,  433,  460,  461,  462,  433,
      433,  433,  433,  463,  433,  433,  464,  465,  466,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  467,  433,  467,
      467,  467,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  468,  433,  468,  468,  468,
      144,  433,  433,  433,  469,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,

      433,  470,  433,  470,  470,  470,  433,  433,  433,  433,
      433,  433,  433,  471,  433,  471,  471,  471,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  472,  433,
      433,  433,  433,  473,  474,  475,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  272,  433,  433,  476,  433,  476,  476,
      476,  433,  433,  469,  433,  433,  433,  433,  433,  433,

      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,    0,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433
    } ;

static const flex_int16_t yy_nxt[1650] =
    {   0,
       30,   31,   32,   30,   33,   34,   35,   36,   30,   35,
       37,   38,   34,   39,   35,   40,   41,   42,   43,   41,
       41,   41,   44,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   45,   46,   30,
       30,   47,   47,   30,   47,   47,   47,   47,   30,   30,
       30,   30,   30,   30,   30,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   30,   47,   30,   47,
       47,   47,   47,   48,   47,   49,   50,   51,   52,   53,
       62,   62,   54,   62,   55,   56,   62,   62,   57,   58,
       62,  339,   62,   59,   62,   62,   60,   64,   88,   90,

       88,   83,   62,   90,   83,   62,   62,   62,   62,   62,
       62,   62,  117,  117,   62,   91,  134,  121,  135,   91,
      121,  153,  167,  112,   86,  150,  168,   86,  112,  170,
      214,  130,  115,  130,  130,  133,  151,  131,  170,  115,
      132,  137,  171,  138,  172,  119,  119,  134,  204,  135,
      154,  139,  139,   63,   63,   62,   84,  256,  150,   84,
       66,  257,  430,   67,   68,  156,   69,   70,   71,  177,
       72,  178,   92,  430,   73,   74,   92,  188,  113,  183,
       75,   76,  184,  113,  189,  167,   77,   78,  190,  168,
       79,  140,  141,  140,  140,  157,  157,  142,  231,  432,

      143,  140,  141,  140,  140,  232,  186,  142,  145,  233,
      143,  186,  187,  140,  141,  140,  140,  163,  145,  142,
      163,  191,  143,  180,  192,  181,  164,  164,   80,   62,
      145,  165,  226,  182,   81,  227,  163,   67,   68,  163,
       69,   70,   71,  194,   72,  164,  164,  431,   73,   74,
      165,  220,  229,  221,   75,   76,  234,  229,  230,  235,
       77,   78,  136,  237,   79,  146,  147,  148,  149,  223,
      139,  224,  195,  255,  258,  146,  147,  148,  149,  225,
      430,  139,  266,  266,  164,  429,  165,  146,  147,  148,
      149,  130,  238,  130,  130,  247,  137,  169,  138,  137,

      132,  138,   80,   94,  428,   95,  139,  265,   96,  139,
      420,   97,   98,  170,   99,  100,  101,  288,  102,  144,
      421,  289,  103,  104,  255,  248,  248,  427,  105,  106,
      186,  186,  139,  426,  107,  108,  425,  259,  109,  260,
      261,  272,  262,  272,  272,  274,  179,  424,  163,  423,
      273,  163,  155,  155,  182,  155,  155,  164,  164,  155,
      155,  278,  165,  155,  296,  155,  155,  422,  171,  279,
      172,  155,  433,  433,  433,  433,  110,   94,  139,   95,
      280,  281,   96,  419,  282,   97,   98,  287,   99,  100,
      101,  180,  102,  181,  415,  182,  103,  104,  302,  302,

      308,  182,  105,  106,  180,  223,  181,  224,  107,  108,
      314,  314,  109,  222,  182,  225,  319,  433,  223,  320,
      224,  225,  413,  321,  225,  229,  229,  297,  225,  298,
      299,  327,  300,  130,  365,  130,  130,  412,  246,  246,
      255,  246,  246,  386,  411,  246,  246,  410,  139,  246,
      110,  122,  246,  287,  366,  367,  246,  246,  409,  123,
      246,  182,  246,  309,  408,  310,  311,  272,  312,  272,
      272,  246,  246,  387,  387,  246,  273,  319,  416,  416,
      140,  141,  140,  140,  407,  225,  142,  124,  416,  416,
      124,  124,  406,  124,  124,  124,  124,  145,  259,  405,

      260,  261,  404,  262,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  403,  124,  402,  124,  124,
      124,  124,  125,  124,  126,  127,  128,  129,  122,  348,
      141,  348,  348,  416,  416,  142,  123,  272,  349,  272,
      272,  401,  351,  400,  352,  399,  145,  416,  416,  398,
      272,  397,  272,  272,  146,  147,  148,  149,  396,  273,
      272,  395,  272,  272,  124,  416,  416,  124,  124,  273,
      124,  124,  124,  124,  297,  393,  298,  299,  394,  300,
      392,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  388,  124,  385,  124,  124,  124,  124,  125,

      124,  126,  127,  128,  129,  140,  141,  140,  140,  330,
      330,  142,  330,  330,  143,  384,  330,  330,  416,  416,
      330,  383,  145,  416,  416,  353,  152,  354,  140,  141,
      140,  140,  382,  381,  142,  355,  321,  356,  342,  321,
      343,  344,  345,  346,  272,  145,  272,  272,  215,  309,
      380,  310,  311,  273,  312,  272,  379,  272,  272,  272,
      378,  272,  272,  377,  273,  376,  372,  372,  273,  372,
      372,  205,  375,  372,  372,  374,  416,  372,  373,  146,
      147,  148,  149,  202,  416,  202,  202,  372,  371,  370,
      369,  272,  203,  272,  272,  416,  416,  289,  204,  416,

      273,  204,  204,  204,  204,  204,  204,  204,  204,  204,
      204,  204,  204,  204,  204,  204,  204,  204,  204,  357,
      205,  358,  289,  205,  205,  368,  205,  205,  205,  205,
      359,  347,  360,  336,  361,  335,  362,  205,  205,  205,
      205,  205,  205,  205,  205,  205,  205,  205,  334,  205,
      333,  205,  205,  205,  205,  332,  205,  206,  207,  208,
      209,  212,  331,  212,  212,  330,  363,  329,  364,  342,
      213,  343,  344,  345,  346,  257,  214,  257,  326,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  325,  215,  324,

      229,  215,  215,  229,  215,  215,  215,  215,  229,  323,
      229,  229,  229,  322,  229,  215,  215,  215,  215,  215,
      215,  215,  215,  215,  215,  215,  222,  215,  315,  215,
      215,  215,  215,  313,  215,  216,  217,  218,  219,  276,
      277,  307,  275,  155,  155,  155,  155,  155,  155,  155,
      155,  155,  155,  303,  155,  155,  246,  246,  365,  328,
      246,  246,  246,  246,  246,  246,  246,  246,  246,  246,
      301,  246,  246,  337,  295,  294,  338,  293,  366,  367,
      292,  186,  339,  186,  340,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,

      339,  339,  339,  186,  341,  291,  186,  341,  341,  186,
      341,  341,  341,  341,  186,  290,  186,  179,  286,  285,
      284,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  283,  341,  167,  341,  341,  341,  341,  342,
      341,  343,  344,  345,  346,  202,  170,  202,  202,  271,
      377,  377,  267,  377,  377,  264,  263,  377,  377,  136,
      204,  377,  254,  204,  204,  204,  204,  204,  204,  204,
      204,  204,  204,  204,  204,  204,  204,  204,  204,  204,
      204,  253,  205,  249,  246,  205,  205,  245,  205,  205,
      205,  205,  244,  243,  242,  241,  240,  239,  236,  205,

      205,  205,  205,  205,  205,  205,  205,  205,  205,  205,
      228,  205,  222,  205,  205,  205,  205,  211,  205,  206,
      207,  208,  209,  212,  210,  212,  212,  201,  385,  385,
      200,  385,  385,  199,  198,  385,  385,  197,  214,  385,
      196,  214,  214,  214,  214,  214,  214,  214,  214,  214,
      214,  214,  214,  214,  214,  214,  214,  214,  214,  193,
      215,  185,  179,  215,  215,  176,  215,  215,  215,  215,
      175,  174,  173,  162,  158,  155,  136,  215,  215,  215,
      215,  215,  215,  215,  215,  215,  215,  215,  133,  215,
      433,  215,  215,  215,  215,  433,  215,  216,  217,  218,

      219,  330,  330,  433,  433,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  433,  330,
      330,  433,  418,  330,  433,  330,  433,  433,  433,  433,
      416,  433,  433,  433,  330,  330,  433,  433,  330,  372,
      372,  416,  416,  372,  372,  372,  372,  372,  372,  372,
      372,  372,  372,  372,  372,  372,  433,  372,  372,  433,
      433,  372,  433,  372,  433,  433,  433,  433,  433,  433,
      433,  433,  372,  372,  433,  433,  372,  377,  377,  433,
      433,  377,  377,  377,  377,  377,  377,  377,  377,  377,
      377,  377,  377,  377,  433,  377,  377,  433,  433,  377,

      433,  377,  433,  433,  433,  433,  433,  433,  433,  433,
      377,  377,  433,  433,  377,  385,  385,  433,  414,  385,
      385,  385,  385,  385,  385,  385,  385,  385,  385,  385,
      385,  385,  433,  385,  385,  433,  433,  385,  433,  385,
      433,  348,  141,  348,  348,  416,  433,  142,  385,  385,
      433,  417,  385,  416,  433,  433,  433,  433,  145,  416,
      433,  416,  433,  433,  416,  416,  433,  416,  416,  416,
      416,  416,  433,  433,  417,  416,  433,  417,  433,  433,
      416,  416,  433,  433,  416,  416,  416,  416,  433,  433,
      416,  433,  433,  433,  433,  433,  416,  416,  433,  433,

      417,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   89,   89,   89,   89,   89,   89,   89,   89,   89,
       89,   93,   93,   93,   93,   93,   93,   93,   93,   93,
       93,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  114,  114,  114,  114,  114,  114,  114,  114,  114,
      114,  116,  116,  116,  116,  116,  116,  116,  116,  116,

      116,  118,  118,  118,  118,  118,  118,  118,  118,  118,
      118,  120,  120,  120,  120,  120,  120,  120,  120,  120,
      120,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,  144,  144,  433,  433,  433,  433,  433,  433,  144,
      159,  159,  159,  159,  159,  160,  160,  160,  160,  160,
      161,  161,  433,  433,  161,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  250,  250,  250,  250,  250,
      251,  251,  251,  251,  251,  252,  252,  433,  433,  252,
      268,  268,  268,  268,  268,  269,  269,  269,  269,  269,
      270,  270,  275,  275,  275,  275,  275,  304,  304,  304,

      304,  304,  305,  305,  305,  305,  305,  306,  306,  316,
      316,  316,  316,  316,  317,  317,  317,  317,  317,  318,
      318,  328,  328,  328,  328,  328,  335,  335,  335,  335,
      335,  350,  350,  350,  350,  433,  433,  350,  350,  205,
      205,  205,  205,  205,  215,  215,  215,  215,  215,  389,
      389,  389,  389,  389,  390,  390,  390,  390,  390,  391,
      391,  433,  433,  391,  414,  414,  414,  414,  414,   29,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,

      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433
    } ;

static const flex_int16_t yy_chk[1650] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        3,    4,    2,    7,    2,    2,    8,    9,    2,    2,
       10,  472,   11,    2,   12,   19,    2,    4,   11,   13,

       12,    7,   20,   14,    8,   17,   21,   22,   23,   24,
       18,   25,   21,   22,   26,   13,   38,   25,   38,   14,
       26,   45,   55,   17,    9,   42,   55,   10,   18,   57,
      463,   36,   19,   36,   36,   57,   42,   36,   58,   20,
       36,   40,   59,   40,   59,   23,   24,   58,  459,   58,
       45,   40,   59,    3,    4,    5,    7,  139,   42,    8,
        5,  139,  432,    5,    5,   49,    5,    5,    5,   68,
        5,   68,   13,  431,    5,    5,   14,   76,   17,   73,
        5,    5,   73,   18,   76,  168,    5,    5,   76,  168,
        5,   41,   41,   41,   41,   49,   49,   41,  106,  427,

       41,   46,   46,   46,   46,  106,   75,   46,   41,  106,
       46,   75,   75,   47,   47,   47,   47,   53,   46,   47,
       53,   77,   47,   71,   77,   71,   53,   53,    5,    6,
       47,   53,  103,   71,    6,  103,   54,    6,    6,   54,
        6,    6,    6,   79,    6,   54,   54,  426,    6,    6,
       54,   98,  105,   98,    6,    6,  107,  105,  105,  107,
        6,    6,  136,  109,    6,   41,   41,   41,   41,  101,
      136,  101,   79,  137,  140,   46,   46,   46,   46,  101,
      425,  137,  146,  146,  165,  423,  165,   47,   47,   47,
       47,   56,  109,   56,   56,  126,  135,   56,  135,  138,

       56,  138,    6,   15,  422,   15,  135,  144,   15,  138,
      410,   15,   15,  171,   15,   15,   15,  182,   15,  144,
      410,  182,   15,   15,  171,  126,  126,  421,   15,   15,
      183,  183,  171,  420,   15,   15,  419,  140,   15,  140,
      140,  155,  140,  155,  155,  156,  179,  413,  163,  412,
      155,  163,  156,  156,  179,  156,  156,  163,  163,  156,
      156,  162,  163,  156,  202,  162,  162,  411,  172,  162,
      172,  162,  144,  144,  144,  144,   15,   16,  172,   16,
      162,  162,   16,  409,  162,   16,   16,  180,   16,   16,
       16,  178,   16,  178,  393,  180,   16,   16,  206,  206,

      212,  178,   16,   16,  181,  221,  181,  221,   16,   16,
      216,  216,   16,  222,  181,  221,  223,  384,  224,  225,
      224,  222,  383,  225,  223,  226,  226,  202,  224,  202,
      202,  247,  202,  254,  284,  254,  254,  381,  247,  247,
      255,  247,  247,  343,  369,  247,  247,  367,  255,  247,
       16,   27,  253,  287,  284,  284,  253,  253,  366,   27,
      253,  287,  253,  212,  364,  212,  212,  276,  212,  276,
      276,  253,  253,  343,  343,  253,  276,  319,  395,  395,
      264,  264,  264,  264,  363,  319,  264,   27,  397,  397,
       27,   27,  362,   27,   27,   27,   27,  264,  329,  361,

      329,  329,  360,  329,   27,   27,   27,   27,   27,   27,
       27,   27,   27,   27,   27,  359,   27,  358,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   28,  275,
      275,  275,  275,  399,  399,  275,   28,  347,  275,  347,
      347,  357,  276,  356,  276,  355,  275,  401,  401,  354,
      277,  353,  277,  277,  264,  264,  264,  264,  352,  277,
      278,  351,  278,  278,   28,  403,  403,   28,   28,  278,
       28,   28,   28,   28,  371,  348,  371,  371,  349,  371,
      346,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,  344,   28,  342,   28,   28,   28,   28,   28,

       28,   28,   28,   28,   28,   44,   44,   44,   44,  331,
      331,   44,  331,  331,   44,  338,  331,  331,  405,  405,
      331,  336,   44,  407,  407,  277,   44,  277,  334,  334,
      334,  334,  325,  322,  334,  278,  321,  278,  348,  320,
      348,  348,  348,  348,  279,  334,  279,  279,  315,  376,
      312,  376,  376,  279,  376,  280,  311,  280,  280,  281,
      310,  281,  281,  309,  280,  308,  373,  373,  281,  373,
      373,  303,  300,  373,  373,  299,  396,  373,  298,   44,
       44,   44,   44,   91,  396,   91,   91,  297,  296,  294,
      290,  282,   91,  282,  282,  396,  396,  289,   91,  396,

      282,   91,   91,   91,   91,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,   91,   91,  279,
       91,  279,  288,   91,   91,  286,   91,   91,   91,   91,
      280,  273,  280,  271,  281,  267,  281,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,   91,  265,   91,
      262,   91,   91,   91,   91,  261,   91,   91,   91,   91,
       91,   96,  260,   96,   96,  259,  282,  258,  282,  415,
       96,  415,  415,  415,  415,  257,   96,  256,  241,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,  240,   96,  239,

      236,   96,   96,  235,   96,   96,   96,   96,  234,  233,
      232,  231,  230,  228,  227,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,  220,   96,  217,   96,
       96,   96,   96,  213,   96,   96,   96,   96,   96,  158,
      158,  210,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  207,  158,  158,  249,  249,  430,  249,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  249,
      203,  249,  249,  272,  199,  198,  272,  197,  430,  430,
      196,  193,  272,  192,  272,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  272,  272,

      272,  272,  272,  191,  272,  190,  189,  272,  272,  188,
      272,  272,  272,  272,  187,  185,  184,  177,  175,  174,
      173,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  169,  272,  166,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  301,  164,  301,  301,  152,
      378,  378,  147,  378,  378,  143,  141,  378,  378,  134,
      301,  378,  132,  301,  301,  301,  301,  301,  301,  301,
      301,  301,  301,  301,  301,  301,  301,  301,  301,  301,
      301,  129,  301,  127,  125,  301,  301,  121,  301,  301,
      301,  301,  119,  117,  115,  113,  112,  110,  108,  301,

      301,  301,  301,  301,  301,  301,  301,  301,  301,  301,
      104,  301,   99,  301,  301,  301,  301,   95,  301,  301,
      301,  301,  301,  313,   92,  313,  313,   88,  386,  386,
       86,  386,  386,   84,   83,  386,  386,   81,  313,  386,
       80,  313,  313,  313,  313,  313,  313,  313,  313,  313,
      313,  313,  313,  313,  313,  313,  313,  313,  313,   78,
      313,   74,   69,  313,  313,   66,  313,  313,  313,  313,
       64,   63,   60,   52,   50,   48,   39,  313,  313,  313,
      313,  313,  313,  313,  313,  313,  313,  313,   37,  313,
       29,  313,  313,  313,  313,    0,  313,  313,  313,  313,

      313,  332,  332,    0,    0,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  333,  332,  332,    0,  333,
      333,    0,  402,  333,    0,  333,    0,    0,    0,    0,
      402,    0,    0,    0,  333,  333,    0,    0,  333,  374,
      374,  402,  402,  374,  374,  374,  374,  374,  374,  374,
      374,  374,  374,  375,  374,  374,    0,  375,  375,    0,
        0,  375,    0,  375,    0,    0,    0,    0,    0,    0,
        0,    0,  375,  375,    0,    0,  375,  379,  379,    0,
        0,  379,  379,  379,  379,  379,  379,  379,  379,  379,
      379,  380,  379,  379,    0,  380,  380,    0,    0,  380,

        0,  380,    0,    0,    0,    0,    0,    0,    0,    0,
      380,  380,    0,    0,  380,  388,  388,    0,  388,  388,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  392,
      388,  388,    0,  392,  392,    0,    0,  392,    0,  392,
        0,  394,  394,  394,  394,  398,    0,  394,  392,  392,
      394,  400,  392,  398,    0,    0,    0,    0,  394,  400,
        0,  404,    0,    0,  398,  398,    0,  406,  398,  404,
      400,  400,    0,    0,  400,  406,    0,  408,    0,    0,
      404,  404,    0,    0,  404,  408,  406,  406,    0,    0,
      406,    0,    0,    0,    0,    0,  408,  408,    0,    0,

      408,  434,  434,  434,  434,  434,  434,  434,  434,  434,
      434,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  436,  436,  436,  436,  436,  436,  436,  436,  436,
      436,  437,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  438,  438,  438,  438,  438,  438,  438,  438,  438,
      438,  439,  439,  439,  439,  439,  439,  439,  439,  439,
      439,  440,  440,  440,  440,  440,  440,  440,  440,  440,
      440,  441,  441,  441,  441,  441,  441,  441,  441,  441,
      441,  442,  442,  442,  442,  442,  442,  442,  442,  442,
      442,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  447,  447,    0,    0,    0,    0,    0,    0,  447,
      448,  448,  448,  448,  448,  449,  449,  449,  449,  449,
      450,  450,    0,    0,  450,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  452,  452,  452,  452,  452,
      453,  453,  453,  453,  453,  454,  454,    0,    0,  454,
      455,  455,  455,  455,  455,  456,  456,  456,  456,  456,
      457,  457,  458,  458,  458,  458,  458,  460,  460,  460,

      460,  460,  461,  461,  461,  461,  461,  462,  462,  464,
      464,  464,  464,  464,  465,  465,  465,  465,  465,  466,
      466,  467,  467,  467,  467,  467,  468,  468,  468,  468,
      468,  469,  469,  469,  469,    0,    0,  469,  469,  470,
      470,  470,  470,  470,  471,  471,  471,  471,  471,  473,
      473,  473,  473,  473,  474,  474,  474,  474,  474,  475,
      475,    0,    0,  475,  476,  476,  476,  476,  476,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,

      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  433
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lex.l"
#line 2 "lex.l"
#include "main.h"
#include "yacc.tab.h"

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size) { \
	int c = fgetc(yyin); \
	result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
	myoffset++;\
	}

extern "C" {
	int yywrap(void);
	int yylex(void);
	ostream& warn(int cur = 0);
	ostream& info(int cur = 0);
	ostream& error(int cur = 0);
	int myoffset;
}

#line 977 "lex.yy.c"

#line 979 "lex.yy.c"

#define INITIAL 0
#define TXT1 1
#define EQU1 2
#define EQU1T 3
#define EQU1JJV 4
#define EQU1JJC 5
#define TXTS 6
#define EQUS 7
#define EQUST 8
#define EQUSJJV 9
#define EQUSJJC 10
#define JJV 11
#define JJC 12
#define ITAL 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 68 "lex.l"


#line 1215 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 434 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1570 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 70 "lex.l"
{
	//cout << "【首】" << yytext;
}
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 74 "lex.l"
{
	//cout << "【题】" << yytext << endl;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "lex.l"
{
	warn() << "下列标点不应该连用`" << yytext << "`。" << endl;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 82 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 86 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 90 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 94 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 98 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 102 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 106 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 110 "lex.l"
{
	error() << "下列不可见字符应该删除。" << endl;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 114 "lex.l"
{
	info() << "下列标点连用前请认真检查语气是否足够强烈`" << yytext << "`。" << endl;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 118 "lex.l"
{
	warn() << "下列中文或标点之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 122 "lex.l"
{
	warn() << "下列外文和标点之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 126 "lex.l"
{
	warn() << "下列标点和外文之间不应该插入空白符。" << endl;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 130 "lex.l"
{
	warn() << "下列中文和外文之间应当插入空格。" << endl;
}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 134 "lex.l"
{
	warn(-1) << "段末应当有标点符号。" << endl;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 138 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 142 "lex.l"
{
	//cout << "【标】" << yytext;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 146 "lex.l"
{
	//cout << "【词】" << yytext;
	if(yyleng == 1 && (('b' <= yytext[0] && yytext[0] <= 'z') || ('K' <= yytext[0] && yytext[0] <= 'N')))
		info() << "字符`" << yytext << "`可能是一个变量，是的话请放在公式中。" << endl;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 152 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑放入公式中并使用变量保存。" << endl;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 156 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑放入公式中并使用变量保存。" << endl;
	//cout << "【数】" << yytext;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 162 "lex.l"
{
	warn() << "一般不应该出现英文标点`" << yytext << "`。" << endl;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 166 "lex.l"
{
	warn() << "非行首一般不应该出现制表符。" << endl;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 170 "lex.l"
{
	//cout << "【符】" << yytext;
}
	YY_BREAK
case 26:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 174 "lex.l"
{
	//cout << "【↓块1】" << yytext + 3;
	BEGIN TXT1;
}
	YY_BREAK
case 27:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 179 "lex.l"
{
	//cout << "【↑块1】" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 184 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 188 "lex.l"
{
	warn() << "文字和字符串之间应当插入空格。" << endl;
	BEGIN TXTS;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 193 "lex.l"
{
	warn() << "标点和字符串之间不应当插入空格。" << endl;
	BEGIN TXTS;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 198 "lex.l"
{
	//cout << "【<s】";
	BEGIN TXTS;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 203 "lex.l"
{
	warn() << "字符串和文字之间应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 208 "lex.l"
{
	warn() << "字符串和标点之间不应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 213 "lex.l"
{
	//cout << "【s>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 218 "lex.l"
{
	error() << "行内字符串不能包含换行。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 223 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 37:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 227 "lex.l"
{
	//cout << "【↓式1】" << endl;
	BEGIN EQU1;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 232 "lex.l"
{
	error() << "行内公式只使用一个`$`。" << endl;
	BEGIN EQU1;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 237 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\" << yytext << "`。" << endl;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 241 "lex.l"
{
	warn() << "在公式中`" << yytext << "`应该写成`\\" << yytext << "`。" << endl;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 245 "lex.l"
{
	info() << "在公式中`mod`一般写成`\\bmod`。" << endl;
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 249 "lex.l"
{
	info() << "在公式中`mod`一般写成`\\bmod`。" << endl;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 253 "lex.l"
{
	info() << "在公式中一般不用星号`*`做乘号，而用叉乘`\\times`、点乘`\\cdot`或省略。" << endl;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 257 "lex.l"
{
	info() << "在公式中一般不用星号`*`做乘号，而用叉乘`\\times`、点乘`\\cdot`或省略。" << endl;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 261 "lex.l"
{
	info() << "在公式中一般不用斜杠`/`做除号，而用除号`\\div`或分数`\\frac{1}{2}`。" << endl;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 265 "lex.l"
{
	info() << "在公式中一般不用斜杠`/`做除号，而用除号`\\div`或分数`\\frac{1}{2}`。" << endl;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 269 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 274 "lex.l"
{
	if(yyleng >= 6)
		warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 279 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 283 "lex.l"
{
	warn() << "数`" << yytext << "`比较长，考虑使用变量保存。" << endl;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 287 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1T;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 292 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 297 "lex.l"
{
	//cout << yytext;
	BEGIN EQU1;
}
	YY_BREAK
case 54:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 302 "lex.l"
{
	//cout << "【↑式1】" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 307 "lex.l"
{
	error() << "行内公式只使用一个`$`。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 312 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 316 "lex.l"
{
	error() << "行内公式前$后不能加空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 321 "lex.l"
{
	warn() << "文字和公式之间应当插入空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 326 "lex.l"
{
	warn() << "标点和公式之间不应当插入空格。" << endl;
	BEGIN EQUS;
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 331 "lex.l"
{
	//cout << "【<e】";
	BEGIN EQUS;
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 336 "lex.l"
{
	//cout << yytext;
	BEGIN EQUST;
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 341 "lex.l"
{
	//cout << yytext;
	BEGIN EQUS;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 346 "lex.l"
{
	//cout << yytext;
	BEGIN EQUS;
}
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 351 "lex.l"
{
	error() << "行内公式不能换行。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 356 "lex.l"
{
	error() << "行内公式后$前不能加空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 361 "lex.l"
{
	warn() << "公式和文字之间应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 366 "lex.l"
{
	warn() << "公式和标点之间不应当插入空格。" << endl;
	BEGIN INITIAL;
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 371 "lex.l"
{
	//cout << "【e>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 376 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 380 "lex.l"
{
	//cout << "【<v】";
	BEGIN JJV;
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 385 "lex.l"
{
	//cout << "【v>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 390 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 394 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQUSJJV;
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 399 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQUS;
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 404 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 408 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQU1JJV;
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 413 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQU1;
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 418 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 422 "lex.l"
{
	//cout << "【<c】";
	BEGIN JJV;
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 427 "lex.l"
{
	//cout << "【c>】";
	BEGIN INITIAL;
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 432 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 436 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQUSJJC;
}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 441 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQUS;
}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 446 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 450 "lex.l"
{
	//cout << "【<v】";
	BEGIN EQU1JJC;
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 455 "lex.l"
{
	//cout << "【v>】";
	BEGIN EQU1;
}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 460 "lex.l"
{
	//cout << yytext;
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 464 "lex.l"
{
	//cout << "【空】";
}
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 468 "lex.l"
{
	//cout << "【换】" << endl;
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 472 "lex.l"
{
	//cout << "【粗】"
}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 476 "lex.l"
{
	//cout << "【斜】"
	BEGIN ITAL;
}
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 481 "lex.l"
{
	error() << "斜体中不能换行。" << endl;
}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 485 "lex.l"
{
	warn() << "斜体一般只用于表示文件名，强调请用加粗。" << endl;
}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 489 "lex.l"
{
	//cout << "【斜】";
	BEGIN INITIAL;
}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 494 "lex.l"
{
	//cout << "【??】" << yytext;
}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 498 "lex.l"
ECHO;
	YY_BREAK
#line 2011 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(TXT1):
case YY_STATE_EOF(EQU1):
case YY_STATE_EOF(EQU1T):
case YY_STATE_EOF(EQU1JJV):
case YY_STATE_EOF(EQU1JJC):
case YY_STATE_EOF(TXTS):
case YY_STATE_EOF(EQUS):
case YY_STATE_EOF(EQUST):
case YY_STATE_EOF(EQUSJJV):
case YY_STATE_EOF(EQUSJJC):
case YY_STATE_EOF(JJV):
case YY_STATE_EOF(JJC):
case YY_STATE_EOF(ITAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 434 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 434 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 433);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 498 "lex.l"


int yywrap(void)
{
	return 1;
}

ostream& error(int cur){
	return cerr << "E " << myoffset + cur << " ";
}

ostream& warn(int cur){
	return cerr << "W " << myoffset + cur << " ";
}

ostream& info(int cur){
	return cerr << "I " << myoffset + cur << " ";
}

